-- boss攻略
Lua_BossStrategyWindow = class("Lua_BossStrategyWindow", Lua_Window)
function Lua_BossStrategyWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_BossStrategyWindow";
	self.skinName = "BossStrategyWindow_skin"; 
	self.showBlackMask = true;
	self.isClickClose = true;
	self.showCloseText = true; 
	self.closeTextPosY = -420;
end

function Lua_BossStrategyWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.standList = Lua_DragList.new(self.content, 222, 66, Lua_AxisDefine.Horizontal);
	self.standList.canDrag = false;
	self.standList:setListCell(Lua_BossStrategyItem, 74, 66, 1);
	self.standList:setLocation(-140, -211, 0);

	self.heroList = Lua_DragList.new(self.content, 252, 87, Lua_AxisDefine.Horizontal);
	self.heroList:setListCell(Lua_BossStrategyItem, 87, 87, 1);
	self.heroList:setCellSpacing(2, 0);
	self.heroList:setRectPivot(3);
	self.heroList:setLocation(1, -211, 0);
end

function Lua_BossStrategyWindow:showWin(param)
	self:superCall("showWin",param)
	if param.bTeam == true then
		self:showBtnListt();
	else
		self:updateBossInfo(param.id);
	end
end

function Lua_BossStrategyWindow:showBtnListt()
	self.tabInfo = Array();
	local list = DataCenter.equipCopyUtil.boss_tag_list;
	for i=1,#list do
		self.tabInfo:add({textStr = list[i][2], id = list[i][1]});
	end
    
    self.btnList = Lua_ButtonList.new(self.content, Lua_AxisDefine.Horizontal);
    self.btnList:setLocation(-70, 432, 0);
    self.btnList:setButtonItem(123, 53);
    self.btnList:setButtonStyle("equipcopy_atlas_2","xui_jmd_button_024","xui_jmd_button_023", 123, 53);
    self.btnList:setButtonText(0, 0, "fcf1db", "8a7d5a", 24, 24, Lua_MyUISettings.huakangFontName, UnityEngine.FontStyle.Normal);
    self.btnList:setClickCallBack(self, self.onTabBtnClick);
    self.btnList:setData(self.tabInfo);
    self.btnList:setSelected(1);
end

function Lua_BossStrategyWindow:onTabBtnClick(val)
	if self.selectTabIndex == val then
		return;
	end
	self.selectTabIndex = val;
	local id = self.tabInfo[val].id;
    self:updateBossInfo(id);
end


--更新boss
function Lua_BossStrategyWindow:updateBossInfo(id)
	self.cfgData = getConfig("equip_copy", id);

	self.campIcon:setAltas("common_altas_2", "xui_common_attribute_"..self.cfgData.id + 6);
	self.bossNameTxt.text = self.cfgData.boss_name;
	self.bossImg:setUrl(self.cfgData.path);
	self.bossIcon:setAltas("equipcopy_atlas_2", self.cfgData.boss_sprite);

	self.upSubdueIcon:setAltas("common_altas_2", "xui_common_attribute_"..self.cfgData.subdue_camp + 6);
	self.upSubdueTxt.text = self.cfgData.des1;

	if self.cfgData.by_subdue_camp ~= nil then
		self.bySubdueIcon:setAltas("common_altas_2", "xui_common_attribute_"..self.cfgData.by_subdue_camp + 6);
		self.bySubdueTxt.text = self.cfgData.by_des;

		self.bySubdueBg:setEnable(false);
		self.bySubdueTxt:setEnable(false);
		self.bySubdueIcon:setEnable(false);
	else
		self.bySubdueBg:setEnable(false);
		self.bySubdueTxt:setEnable(false);
		self.bySubdueIcon:setEnable(false);
	end

	self:showSkills();

	local info = self:dealwithStandAndHeroData(self.cfgData.stand_list, 1);
	self.standList:setArrayData(info);

	info = self:dealwithStandAndHeroData(self.cfgData.hero_list, 2);
	self.heroList.canDrag = #info >= 3;
	self.heroList:setArrayData(info);
	self.heroList:moveToIndex(1, true);
end


-- 处理站位或英雄数据携带各自的类型 _type：1站位 2英雄
function Lua_BossStrategyWindow:dealwithStandAndHeroData(data,  _type)
	local param = {};
	for k, v in ipairs(data) do
		param[k] = {id = v, type = _type};
	end
	return param;
end

-- 技能展示
function Lua_BossStrategyWindow:showSkills()
	local posDic = {{-204, 226.5}, {196.5, 226.5}, {-204, 85.5}, {196.5, 85.5}};
	
	if self.skillInfo == nil then
		self.skillInfo = Array();
	end
	for i=1,self.skillInfo:getSize() do
		self.skillInfo[i]:setEnable(false);
	end
	local skillList = self.cfgData.skill_list; -- 技能id列表
	local skillItem;
	local len = #skillList;
	for i = 1, len do
		if i < len then
			skillItem = self.skillInfo[i];
			if skillItem == nil then
				skillItem = Lua_BossStrategySkillItem.new(self.content);
				self.skillInfo:add(skillItem);
			end
			skillItem:setEnable(true);
			skillItem:setData(skillList[i]);
			skillItem:setLocation(posDic[i][1], posDic[i][2], 0);
		end
	end
	self.isBuildSkill = true;
end

function Lua_BossStrategyWindow:dispose()
	if self.rankList ~= nil then
		self.rankList:dispose();
		self.rankList = nil;
	end

	if self.btnList ~= nil then
		self.btnList:dispose();
		self.btnList = nil;
	end
	if self.skillInfo ~= nil then
		self.skillInfo:dispose();
		self.skillInfo:clear();
		self.skillInfo = nil;
	end
	self:superCall("dispose");
end










Lua_BossStrategyItem = class("Lua_BossStrategyItem", Lua_ListCell);
function Lua_BossStrategyItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_BossStrategyItem:buildShowItem()
	self:superCall("buildShowItem");

	self.standIcon = UICreate.createUIAtlasImage(self.content, "", "", 0, 0, 0, 0);
	self.heroIcon = Lua_ItemIcon.new(self.content);
	self.heroIcon:setScale(0.7, 0.7);
end

function Lua_BossStrategyItem:setData(data)
	self._data = data;
	if data == nil then
		return;
	end

	if data.type == 1 then
		local standInfo = DataCenter.heroLineupUtil:getStandInfoByType(data.id);
		self.standIcon:setAltas(standInfo.stand_atlas, standInfo.stand_icon);
	elseif data.type == 2 then
		local heroVo = Lua_HeroVo.new(data.id);
		self.heroIcon:setData(heroVo);
	end
	self.standIcon:setEnable(data.type == 1);
	self.heroIcon:setEnable(data.type == 2);
end

function Lua_BossStrategyItem:dispose()
	if self.standIcon ~= nil then
		self.standIcon:dispose();
		self.standIcon = nil;
	end
	if self.heroIcon ~= nil then
		self.heroIcon:dispose();
		self.heroIcon = nil;
	end
	self:superCall("dispose");
end










Lua_BossStrategySkillItem = class("Lua_BossStrategySkillItem", Lua_ListCell);
function Lua_BossStrategySkillItem:ctor(p)
	self:superCall("ctor", p, "BossStrategySkillItem_skin");
end

function Lua_BossStrategySkillItem:buildShowItem()
	self:superCall("buildShowItem");

	self.skillItem = Lua_SkillIconItem.new(self.content);
	self.skillItem:setCanClick(true);
	self.skillItem:setScale(0.8, 0.8);
end

function Lua_BossStrategySkillItem:setData(data)
	self._data = data;
	if data == nil then
		return;
	end

	local config = Lua_SkillConfigData.getConfigData(data);
	self.skillItem:setData(config);

	self.skillNameTxt.text = config.name;
	self.skillNameTxt:resetSize();
	self.skillNameBg:SetDimensions(self.skillNameTxt.width + 38, 30)
end

function Lua_BossStrategySkillItem:dispose()
	if self.skillItem ~= nil then
		self.skillItem:dispose();
		self.skillItem = nil;
	end
	self._data = nil;

	self:superCall("dispose");
end