-- 组队
Lua_MoreTeamPanel = class("Lua_MoreTeamPanel", Lua_DisplayObject);
function Lua_MoreTeamPanel:ctor(p)
	self:superCall("ctor", p, "MoreTeamPanel_skin");
end

function Lua_MoreTeamPanel:buildShowItem()
	self:superCall("buildShowItem");
	self.forceNum = Lua_NumberImage.new(self.forceObj);
	self.forceNum.pivot = 1;
	self.forceNum.numOffsetX = -5;
	self.forceNum.numAtlas = "number";
	self.forceNum.preStr = "xui_zssb_number_";
	self.forceNum:setLocation(-240, -196, 0);

	self.rewardList = Lua_DragList.new(self.content, 650, 112, Lua_AxisDefine.Horizontal);
	self.rewardList:setListCell(Lua_MoreRewardCell, 112, 112, 1);
	self.rewardList:setCellSpacing(3, 0);
	self.rewardList:setRectPivot(3);
	self.rewardList:setRectAnchor(7);
	self.rewardList:setLocation(-300, 417);

	self.difficultyList = Lua_DragList.new(self.content, 710, 89, Lua_AxisDefine.Horizontal);
	self.difficultyList:setListCell(Lua_BossDifficultyCell, 168, 89, 1);
	self.difficultyList:setCellSpacing(4, 0);
	self.difficultyList:setRectPivot(3);
	self.difficultyList:setRectAnchor(7);
	self.difficultyList:setLocation(-355, 293);

	self.teamOpenState = DataCenter.equipCopyUtil.teamOpenState;
	self.joinBtn:setGray( not self.teamOpenState);
	self.createBtn:setGray( not self.teamOpenState);

	self.ruleBtn:addClickFuntion(self, self.onHelpBtnClick); -- 规则说明
	self.warBtn:addClickFuntion(self, self.onWarBtnClick); -- 战令
	self.shopBtn:addClickFuntion(self, self.onShopBtnClick); -- 商店奖励
	self.bossTipsBtn:addClickFuntion(self, self.onBossBtnClick); -- boss攻略
	self.harvestBtn:addClickFuntion(self, self.onHarvestBtnClick); -- 今日收获
	self.joinBtn:addClickFuntion(self, self.onJoinBtnClick); -- 加入队伍
	self.createBtn:addClickFuntion(self, self.onCreateBtnClick); -- 创建队伍

	self:updateBtnRedPoint();
	
	self:addLuaEvent("EQUIP_COPY_INFO", self, self.updateCopyInfo);
	self:addLuaEvent("ON_DIFFICULTY_CELL", self, self.updateDifficultyInfo); -- 难度选中
	self:addLuaEvent("EQUIP_COPY_TEAM_INFO", self, self.updateBtnState); -- 离队/加入/创建/被队长踢出/系统提出  更新按钮状态更新   
	self:addLuaEvent("EQUIPCOPY_UPDATE_TEAM_BTNREDPOINT", self, self.updateBtnRedPoint); -- 按钮红点更新
	self:addLuaEvent("UPDATE_EQUIPCOPY_TEAM_REWARD_COUNT", self, self.updateShowRewardCount); -- 更新奖励次数
end

function Lua_MoreTeamPanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);
end

function Lua_MoreTeamPanel:updateCopyInfo()
	-- 副本
	local list = getConfig("equip_copy_more");
	local equipCopyData = DataCenter.equipCopyData;
	local index = equipCopyData.max_difficulty == 0 and 1 or equipCopyData.max_difficulty;
	self.difficultyList:setArrayData(list);
	self.difficultyList:moveToIndex(index, true, false);
	self.difficultyList:setSelected(index);
	self:updateDifficultyInfo(list[index]);

	self.tipsTxt:setEnable((index < #list)); -- 未达最高难度显示

	self:updateShowRewardCount();
	self:updateBtnState();
	self:showBossModel(list[index]);
end

function Lua_MoreTeamPanel:updateShowRewardCount()
	local equipCopyData = DataCenter.equipCopyData;
	local equipCopyUtil = DataCenter.equipCopyUtil;
	if equipCopyData.reward_times > 0 then -- 有挑战奖励次数
		self.showCountTxt.text = LanUtil.formateStr(420006, equipCopyData.reward_times, equipCopyUtil.more_reward_limit);
	else
		if equipCopyData.extra_reward_times > 0 then -- 有协助奖励次数
			self.showCountTxt.text = LanUtil.formateStr(420007, equipCopyData.extra_reward_times, equipCopyUtil.more_extra_reward_count);
		else
			self.showCountTxt.text = LanUtil.formateStr(420008, equipCopyData.help_times, equipCopyUtil.more_extra_limit);
		end
	end
end

-- 按钮状态更新
function Lua_MoreTeamPanel:updateBtnState()
	if DataCenter.equipCopyData.team_id ~= 0 then
		self.createBtn:setEnable(false);
		self.joinBtn:setLangValue(420009);
		self.joinBtn:setLocation(0, 170, 0);
	else
		self.createBtn:setEnable(true);
		self.joinBtn:setLangValue(420010);
		self.joinBtn:setLocation(155, 170, 0);
	end
end

-- 难度选中
function Lua_MoreTeamPanel:updateDifficultyInfo(data)
	if self.tab_select == data.difficulty then
		return;
	end
	self.tab_select = data.difficulty;

	self.bossNameTxt.text = data.boss_name;
	if data.force ~= nil then
		self.forceNum.num = data.force;
	end
	self.forceNum:setEnable(data.force ~= nil);

	self.rewardList:setArrayData(data.reward_list);
end

-- 模型展示
function Lua_MoreTeamPanel:showBossModel(moreInfo)
	local id = moreInfo.boss_info[1];
	local boosId = DataCenter.equipCopyUtil:getTheBossId(id);
	Lua_MsgUtil.callFunc("EQUIP_COPY_SHOW_MODEL", boosId);
end


-- 商店
function Lua_MoreTeamPanel:onShopBtnClick()
	DataCenter.funcPathUtil:gotoFunction(1044) -- 1044：寂灭商店跳转id
end

-- 战令
function Lua_MoreTeamPanel:onWarBtnClick()
	DataCenter.funcPathUtil:gotoFunction(1042) -- 1042：寂灭岛战令跳转id
end

-- boss攻略
function Lua_MoreTeamPanel:onBossBtnClick()
	Lua_WindowUtil.openWin("Lua_BossStrategyWindow", Lua_WinParam.ACTION_OPEN, {bTeam = true});
end

-- 今日收获
function Lua_MoreTeamPanel:onHarvestBtnClick()
	Lua_WindowUtil.openWin("Lua_HarvestPackWindow", Lua_WinParam.ACTION_OPEN, 2);
end

-- 加入队伍
function Lua_MoreTeamPanel:onJoinBtnClick()
	if not self.teamOpenState then
		OperateAlert.showLangValue(420011);
		return;
	end

	local index = 1;
	if DataCenter.equipCopyData.team_id ~= 0 then 
		index = 2;
	end
	Lua_WindowUtil.openWin("Lua_TeamSaloonWindow", Lua_WinParam.ACTION_OPEN, index);
end

-- 创建队伍
function Lua_MoreTeamPanel:onCreateBtnClick()
	if not self.teamOpenState then
		OperateAlert.showLangValue(420011);
		return;
	end
	Lua_WindowUtil.openWin("Lua_CreateTeamWindow", Lua_WinParam.ACTION_OPEN, 1);
end

-- 规则
function Lua_MoreTeamPanel:onHelpBtnClick() 
	local tipsData = {des = LanUtil.getValue(420012), posX = 160, posY = -250};
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

-- 按钮上的红点显示
function Lua_MoreTeamPanel:updateBtnRedPoint()
	if self.warMarkRedPoint == nil then -- 战令红点
		self.warMarkRedPoint = Lua_RedPointIcon.new(self.btnObj);
		self.warMarkRedPoint:createRedPointEff();
		self.warMarkRedPoint:setRectAnchor(1);
		self.warMarkRedPoint:setLocation(338, 429, 0);
	end
	if self.teamHarvestRedPoint == nil then -- 今日收获红点
		self.teamHarvestRedPoint = Lua_RedPointIcon.new(self.btnObj);
		self.teamHarvestRedPoint:createRedPointEff();
		self.teamHarvestRedPoint:setRectAnchor(1);
		self.teamHarvestRedPoint:setLocation(338, 225, 0);
	end

	local warMark = DataCenter.equipCopyData.equipCopyWarMarkRedDot; -- 战令
	local teamHarvest = DataCenter.equipCopyData.equipCopyTeamHarvestRedDot; -- 今日收获
	self.warMarkRedPoint:updateRedPointShow(warMark);
	self.teamHarvestRedPoint:updateRedPointShow(teamHarvest);
end

function Lua_MoreTeamPanel:dispose()
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
	if self.difficultyList ~= nil then
		self.difficultyList:dispose();
		self.difficultyList = nil;
	end
	if self.mondlInfo ~= nil then
		self.mondlInfo:dispose();
		self.mondlInfo:clear();
		self.mondlInfo = nil;
	end
	if self.warMarkRedPoint ~= nil then
		self.warMarkRedPoint:dispose();
		self.warMarkRedPoint = nil;
	end
	if self.teamHarvestRedPoint ~= nil then
		self.teamHarvestRedPoint:dispose();
		self.teamHarvestRedPoint = nil;
	end
	if self.modelEffImg ~= nil then 
		self.modelEffImg:dispose();
		self.modelEffImg = nil;
	end
	-- self.groupImage = nil;

	self:superCall("dispose");
end










Lua_MoreRewardCell = class("Lua_MoreRewardCell", Lua_ListCell);
function Lua_MoreRewardCell:ctor(p)
	self:superCall("ctor", p);
end

function Lua_MoreRewardCell:buildShowItem()
	self:superCall("buildShowItem");

	self.itemIcon = Lua_ItemIcon.new(self.content);
	self.itemIcon:setCanClick(false);
	self.itemIcon:setScale(0.9, 0.9);
end

function Lua_MoreRewardCell:setData(list)
	if list == nil then
		return;
	end

	self.data = Lua_ToolVo.createToolVo(list[1], list[2]);
	self.itemIcon:setData(self.data);
end

function Lua_MoreRewardCell:onPressClick()
	if self.data == nil then
		return;
	end
	DataCenter.packUtil:showItemInfo(self.data);
end

function Lua_MoreRewardCell:dispose()
	if self.itemIcon ~= nil then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	self:superCall("dispose");
end










Lua_BossDifficultyCell = class("Lua_BossDifficultyCell", Lua_ListCell);
function Lua_BossDifficultyCell:ctor(p)
	self:superCall("ctor", p, "BossDifficultyCell_skin");
end

function Lua_BossDifficultyCell:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_BossDifficultyCell:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	self.desTxt.text = data.name;

	self.isUnlock = DataCenter.equipCopyData.max_difficulty >= data.difficulty;
	self.maskIcon:setEnable(not self.isUnlock);
	self.unlock:setEnable(not self.isUnlock);
end


function Lua_BossDifficultyCell:onPressClick()
	if self.data == nil then
		return;
	end

	if self.isUnlock == false then
		OperateAlert.showLangValue(420013);
		return
	end
	Lua_MsgUtil.callFunc("ON_DIFFICULTY_CELL", self.data);
	return true;
end

function Lua_BossDifficultyCell:onSelectionChange(bSelect)
	self:superCall("onSelectionChange", bSelect);

	if bSelect == true then
		self.itemBg:setAltas("equipcopy_atlas_1", "xui_jmd_button_021");

		self.desTxt.colorStr = Lua_ColorDefine.transColorStr("452B2C");
	else
		self.itemBg:setAltas("equipcopy_atlas_1", "xui_jmd_button_022");

		if self.isUnlock then
			self.desTxt.colorStr = Lua_ColorDefine.transColorStr("D5C39E");
		else
			self.desTxt.colorStr = Lua_ColorDefine.transColorStr("908181");
		end
	end
end

function Lua_BossDifficultyCell:dispose()
	self.data = nil;
	self:superCall("dispose");
end