-- 大厅
Lua_SaloonPanel = class("Lua_SaloonPanel", Lua_DisplayObject);
function Lua_SaloonPanel:ctor(p)
	self:superCall("ctor", p, "SaloonPanel_skin");
end

function Lua_SaloonPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.diffSet = nil; -- 难度筛选索引
	self.forceSet = nil; -- 战斗筛选索引

	self.dragList = Lua_DragList.new(self.content, 704, 850 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.dragList:setListCell(Lua_SaloonCell, 704, 230, 1);
	self.dragList:setCellSpacing(0, 10);
	self.dragList:setRectAnchor(1);
	self.dragList:setLocation(0, -720 - self.adaptHeight / 2);

	self.updateBtn:addClickFuntion(self, self.onUpdateBtnClick); -- 刷新
	self.inviteBtn:addClickFuntion(self, self.onInviteBtnClick); -- 邀请信息
	self.autoBtn:addClickFuntion(self, self.onAutoBtnClick); -- 自动加入
	self.createBtn:addClickFuntion(self, self.onCreateBtnClick); -- 创建队伍

	self.diffBg:addClickFuntion(self, self.onDiffBtnClick); -- 难度筛选
	self.forceBg:addClickFuntion(self, self.onForceBtnClick); -- 战力筛选
	
	self:addLuaEvent("EQUIP_COPY_TEAM_INFO", self, self.updateShowInfo); -- 界面数据
	self:addLuaEvent("EQUIP_COPY_TEAM_SALOON", self, self.updateShowInfo);
	self:addLuaEvent("UPDATE_AUTO_JOIN_TIME_STATE", self, self.updateAutoJionState); -- 更新自动加入状态
	Lua_ProxyManager.getProxy("Lua_EquipCopyProxy"):sTeamSaloon(1, DataCenter.equipCopyData.max_difficulty);

	self:showSetInfo();
end

function Lua_SaloonPanel:onScreenResize(adaptHeight)
	if self.adaptHeight ~= adaptHeight then
		self:superCall("onScreenResize", adaptHeight);

		self.dragList:setContentRect(704, 850 + adaptHeight);
		self.dragList:setLocation(0, -720 - adaptHeight / 2);
	end
end

function Lua_SaloonPanel:showSetInfo()
	local diffIndex;
	self.diffScreenInfo,diffIndex = DataCenter.equipCopyUtil:getDiffScreenInfo(DataCenter.equipCopyData.max_difficulty); -- 难度数据/难度筛选索引

	self.forceScreenInfo = DataCenter.equipCopyUtil:forceScreenInfo();
	local forceIndex = self.forceScreenInfo:getSize(); -- 战斗筛选索引
	self:updateForceLimit(forceIndex);
	self:updateDiffLimit(diffIndex);
end

function Lua_SaloonPanel:updateShowInfo()
	if DataCenter.equipCopyData.team_id == 0 then
		self.createBtn:setLangValue(420015);
	else
		self.createBtn:setLangValue(420016);
	end
	
	-- 队伍
	local arr = DataCenter.equipCopyData.teamSaloonInfo;
	self.autoBtn:setGray(arr == nil or arr:getSize() == 0);
	self.noneObj:SetActive(arr == nil or arr:getSize() == 0);

	self.dragList:setArrayData(arr);
	self:updateAutoJionState();
	self:updateBtnRedPoint();
end

function Lua_SaloonPanel:updateAutoJionState()
	if DataCenter.equipCopyData.is_auto_join == 1 then
		self.autoBtn:setLangValue(420017);
	else
		self.autoBtn:setLangValue(420018);
	end
end

function Lua_SaloonPanel:updateForceLimit(index)
	self.forceIndex = index;
	self.forceSet = self.forceScreenInfo[index].setType; -- 战力设置类型
	self.forcedesTxt.text = self.forceScreenInfo[index].showDes;
end

function Lua_SaloonPanel:updateDiffLimit(index)
	self.diffIndex = index;
	self.diffSet = self.diffScreenInfo[index].setType; -- 难度设置类型
	self.diffdesTxt.text = self.diffScreenInfo[index].showDes;
end

-- 刷新
function Lua_SaloonPanel:onUpdateBtnClick() 
	self:sendTeamSaloonMsg();
end

-- 红点显示
function Lua_SaloonPanel:updateBtnRedPoint()
	if self.redDotIcon == nil then -- 今日收获红点
		self.redDotIcon = Lua_RedPointIcon.new(self.content,Lua_RedPointList.EquipCopy_Team_Invite);
		self.redDotIcon:createRedPointEff();
		self.redDotIcon:setRectAnchor(7);
		self.redDotIcon:setLocation(-93, 195, 0);
	end
end

-- 邀请信息
function Lua_SaloonPanel:onInviteBtnClick()
	Lua_WindowUtil.openWin("Lua_ECInvitationJournalWindow", Lua_WinParam.ACTION_OPEN);
end

-- 自动加入
function Lua_SaloonPanel:onAutoBtnClick()
	if DataCenter.equipCopyData.is_auto_join == 1 then -- 自动匹配
		local tipsData = { des = LanUtil.getValue(420019), btnType = 1, owner = self, sureFun = self.onCancelMatching };
		Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
		return
	else
		if DataCenter.equipCopyData.team_id ~= 0 then--已在队伍中
			self:showTips();
		else
			self:sendSutoJoin()
		end
	end
end

function Lua_SaloonPanel:onCancelMatching()
	Lua_ProxyManager.getProxy("Lua_EquipCopyProxy"):sSutoJoin(0);
end

-- 是否切换队伍
function Lua_SaloonPanel:showTips()
	local tipsData = { des = LanUtil.getValue(420020), btnType = 1, owner = self, sureFun = self.sendSutoJoin };
	Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_SaloonPanel:sendSutoJoin()
	Lua_ProxyManager.getProxy("Lua_EquipCopyProxy"):sSutoJoin(1, self.forceSet, self.diffSet);
end

-- 创建队伍
function Lua_SaloonPanel:onCreateBtnClick()
	if DataCenter.equipCopyData.team_id == 0 then
		Lua_WindowUtil.openWin("Lua_CreateTeamWindow", Lua_WinParam.ACTION_OPEN, 1);
	else
		Lua_WindowUtil.openWin("Lua_TeamSaloonWindow", Lua_WinParam.ACTION_OPEN, 2);
	end
end

-- 战力筛选
function Lua_SaloonPanel:onForceBtnClick()
	local list = {
		owner = self,
		selectIndex = self.forceIndex,
		showInfo = self.forceScreenInfo,
		callBack = self.onForceCallBack,
		x = 25,
		y = 388,
		anchor = UIUtils.Anchor.Bottom
	};
	Lua_WindowUtil.openWin("Lua_ScreenSelectWindow", Lua_WinParam.ACTION_OPEN, list);
end

-- 战力
function Lua_SaloonPanel:onForceCallBack(index)
	if self.forceIndex == index then
		return;
	end
	self:updateForceLimit(index);
	self:sendTeamSaloonMsg();
end

-- 难度筛选
function Lua_SaloonPanel:onDiffBtnClick()
	local list = {
		owner = self,
		selectIndex = self.diffIndex,
		showInfo = self.diffScreenInfo,
		callBack = self.onDiffCallBack,
		x = 244,
		y = 388,
		anchor = UIUtils.Anchor.Bottom
	};
	Lua_WindowUtil.openWin("Lua_ScreenSelectWindow", Lua_WinParam.ACTION_OPEN, list);
end

-- 难度
function Lua_SaloonPanel:onDiffCallBack(index)
	if self.diffIndex == index then
		return;
	end
	self:updateDiffLimit(index);
	self:sendTeamSaloonMsg();
end

-- 请求战力/难度筛选
function Lua_SaloonPanel:sendTeamSaloonMsg() 
	Lua_ProxyManager.getProxy("Lua_EquipCopyProxy"):sTeamSaloon(self.forceSet, self.diffSet);
end

function Lua_SaloonPanel:dispose()
	if self.dragList ~= nil then
		self.dragList:dispose();
		self.dragList = nil;
	end
	if self.redDotIcon ~= nil then
		self.redDotIcon:dispose();
		self.redDotIcon = nil;
	end

	self:superCall("dispose");
end










-- 大厅队伍信息
Lua_SaloonCell = class("Lua_SaloonCell", Lua_ListCell);
function Lua_SaloonCell:ctor(p)
	self:superCall("ctor", p, "SaloonCell_skin");
end

function Lua_SaloonCell:buildShowItem()
	self:superCall("buildShowItem");
	self.subBtn:addClickFuntion(self, self.onSubBtnClick);
end

function Lua_SaloonCell:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	self.nameTxt.text = LanUtil.formateStr(420021, data.leader_name);

	self.subBtn:setLangValue(420022);
	self.subBtn:setStyle(1);
	if data.isForec == false then
		self.subBtn:setLangValue(420023);
		self.subBtn:setStyle(3);
	end
	if data.is_full == 1 then
		self.subBtn:setLangValue(420024);
		self.subBtn:setStyle(3);
	end

	local showForec = data.showForec == 0 and LanUtil.getValue(420025) or data.showForec;
	self.forceTxt.text = LanUtil.formateStr(420026, showForec);
	self.allForceTxt.text = LanUtil.formateStr(420027, data.total_force);
	self:showIcon(data.team_list);
end

function Lua_SaloonCell:showIcon(list)
	if self.teamArr == nil then
		self.teamArr = Array();
	end

	local item;
	for i = 1, 3 do
		item = self.teamArr[i];
		if item == nil then
			item = Lua_SaloonTeamItem.new(self.content);
			self.teamArr:add(item);
		end
		item.index = i;
		item:setData(list[i]);
		item:setLocation(-264 + (i - 1) * 133, -28);
		item:setEnable(true);
	end
end

function Lua_SaloonCell:onSubBtnClick()
	if self.data.isForec == false then -- 战力不足
		OperateAlert.showLangValue(420023);
		return;
	elseif self.data.is_full == 1 then -- 已满员
		OperateAlert.showLangValue(420024);
		return
	end
	
	if DataCenter.equipCopyData.team_id == 0 then
		self:sendJoinTeam();
	else
		self:showTips();
	end
end

function Lua_SaloonCell:sendJoinTeam()
	Lua_ProxyManager.getProxy("Lua_EquipCopyProxy"):sJoinTeam(self.data.id);
end

-- 是否切换队伍
function Lua_SaloonCell:showTips()
	local tipsData = { des = LanUtil.getValue(420020), btnType = 1, owner = self, sureFun = self.sendJoinTeam };
	Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_SaloonCell:dispose()
	if self.teamArr ~= nil then
		self.teamArr:dispose();
		self.teamArr:clear();
		self.teamArr = nil;
	end
	self:superCall("dispose");
end










-- 队伍
Lua_SaloonTeamItem = class("Lua_SaloonTeamItem", Lua_DisplayObject);
function Lua_SaloonTeamItem:ctor(p)
	self:superCall("ctor", p, "SaloonTeamItem_skin");
end

function Lua_SaloonTeamItem:buildShowItem()
	self:superCall("buildShowItem");

	self.palyerHead = Lua_AvatarItem.new(self.content);
	self.palyerHead:setScale(0.9, 0.9);
	self.palyerHead:setSiblingIndex(2);
end

function Lua_SaloonTeamItem.Set:index(index)
	self.camp = DataCenter.equipCopyData.camp_list[index];
end

function Lua_SaloonTeamItem:setData(data)
	self.campIcon:setAltas("common_altas_2", "xui_common_attribute_"..self.camp);

	if data == nil then
		self.palyerHead:setEnable(false);
	else
		self.palyerHead:setEnable(true);
		self.palyerHead:setRoleDressUp(data.show_role.dress_info);
		self.palyerHead:setRoleLevel(data.show_role.level);
	end
end

function Lua_SaloonTeamItem:dispose()
	if self.palyerHead ~= nil then
		self.palyerHead:dispose();
		self.palyerHead = nil;
	end
	self:superCall("dispose");
end