-- 筛选列表
-- local list = {};
-- list.width = 130; -- 背景宽度
-- list.high = 190; -- 背景高度
-- list.x = 140;--x
-- list.y = -137;--y
-- list.selectIndex = 1; -- 默认选中列表索引
-- list.showInfo = showInfo; -- 列表数据 arr:add({index = 1, showDes = "描述", isUnlock = false});
-- list.owner = self;
-- list.callBack = self.onCallBack();
Lua_ScreenSelectWindow = class("Lua_ScreenSelectWindow", Lua_Window);
function Lua_ScreenSelectWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_ScreenSelectWindow";
	self.layer = MainWinDefine.TIPS_WINDOW_LAYER;
	self.isFullSizeWin = true;
	self.showBlackMask = true;
	self.isClickClose = true;
	self.blackAlpha = 0.01;
end

function Lua_ScreenSelectWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.showContainer = Lua_WindowUtil.createContaner(self.content, Vector3.zero);
	self:addLuaEvent("ON_SCREEN_SELECT_CELL", self, self.updateScreenSelect); -- 选中
end

function Lua_ScreenSelectWindow:showWin(param)
	self:superCall("showWin", param);

	self.owner = param.owner;
	self.callBack = param.callBack;

	if param.anchor ~= nil then
		LuaUtil.setObjAnchor(self.showContainer, param.anchor);
	end
	LuaUtil.setObjPos(self.showContainer, param.x, param.y, 0);

	local width = param.width == nil and 190 or param.width;
	local high = param.high == nil and 208 or param.high;
	local showBgAtlas = param.showBgAtlas == nil and "equipcopy_atlas_1" or param.showBgAtlas;
	local showBgSprite = param.showBgSprite == nil and "xui_jmd_widget_17" or param.showBgSprite;
	self.showBg = UICreate.createUIAtlasImage(self.showContainer, showBgAtlas, showBgSprite, 0, 0, width, high);

	local listWidth = param.listWidth == nil and width or param.listWidth;
	local listHeight = param.listHeight == nil and high - 8 or param.listHeight;
	local itemHeight = param.itemHeight == nil and 48 or param.itemHeight;
	self.dragList = Lua_DragList.new(self.showContainer, listWidth, listHeight, Lua_AxisDefine.Vertical);
	self.dragList:setListCell(Lua_ScreenSelectCell, listWidth, itemHeight, 1);
	self.dragList:setCellSpacing(0, 2);
	self.dragList:setLocation(0, 0);

	if param.showInfo ~= nil then
		local bgWidth = param.bgWidth == nil and 188 or param.bgWidth;
		local bgHeight = param.bgHeight == nil and 44 or param.bgHeight;
		local arr = Array();
		for i = 1, param.showInfo:getSize() do
			param.showInfo[i].bgWidth = bgWidth;
			param.showInfo[i].bgHeight = bgHeight;
			param.showInfo[i].bgAtlas = param.bgAtlas == nil and "equipcopy_atlas_1" or param.bgAtlas;
			param.showInfo[i].bgSprite = param.bgSprite == nil and "xui_jmd_widget_18" or param.bgSprite;
			param.showInfo[i].desDic = param.desDic == nil and nil or param.desDic;
			arr:add(param.showInfo[i]);
		end
		self.dragList:setArrayData(arr);
		self.dragList:moveToIndex(param.selectIndex, true, false);
		self.dragList:setSelected(param.selectIndex);
	end
end

function Lua_ScreenSelectWindow:updateScreenSelect(index) 
	if self.selectIndex == index then
		return;
	end
	self.selectIndex = index;

	self:onCallBack(index);
	self:hide();
end

-- 回调
function Lua_ScreenSelectWindow:onCallBack(index)
	if self.owner ~= nil and self.callBack ~= nil then
		self.callBack(self.owner, index);
	end
end

function Lua_ScreenSelectWindow:hide()
	if self.showData.onHideCallBack ~= nil then
		self.showData.onHideCallBack(self.owner);
	end
	self:superCall("hide");
end

function Lua_ScreenSelectWindow:dispose()
	if self.showContainer ~= nil and IsNil(self.showContainer) == false then
		UnityEngine.GameObject.Destroy(self.showContainer);
		self.showContainer = nil;
	end
	if self.dragList ~= nil then
		self.dragList:dispose();
		self.dragList = nil;
	end
	self.owner = nil;
	self.callBack = nil;

	self:superCall("dispose");
end










Lua_ScreenSelectCell = class("Lua_ScreenSelectCell", Lua_ListCell);
function Lua_ScreenSelectCell:ctor(p)
	self:superCall("ctor", p);
end

function Lua_ScreenSelectCell:buildShowItem()
	self:superCall("buildShowItem");

	self.bg = UICreate.createUIAtlasImage(self.content, "common_altas_1", "xui_common_edit_002", 0, 0, 0, 0);

	self.lockIcon = UICreate.createUIAtlasImage(self.content, "common_altas_3", "xui_common_label_13", 0, 0, 0, 0);
	self.lockIcon.pivot = UIUtils.Pivot.Right;

	self.selectIcon = UICreate.createUIAtlasImage(self.content, "equipcopy_atlas_1", "xui_jmd_widget_31", 0, 0, 0, 0);
	self.selectIcon.pivot = UIUtils.Pivot.Right;

	self.desTxt = UICreate.createLabel(self.content, nil, -75, 0, 100, 24, 24);
	self.desTxt.pivot = UIUtils.Pivot.Left;
	self.desTxt.alignmentValue = 3;
	self.desTxt.horizontalOverflowValue = 1;
	self.desTxt.colorStr = Lua_ColorDefine.transColorStr("F0EBE3");

	self.lockIcon:setEnable(false);
	self.selectIcon:setEnable(false);
end

function Lua_ScreenSelectCell:setData(data)
	self._data = data;
	if data == nil then
		return;
	end

	self:setTransform();

	self.desTxt.text = data.showDes;
	self.lockIcon:setEnable(not data.isUnlock);
end

function Lua_ScreenSelectCell:setTransform()
	self.bg:setAltas(self._data.bgAtlas, self._data.bgSprite);
	self.bg:SetDimensions(self._data.bgWidth, self._data.bgHeight);

	local posX = self._data.bgWidth / 2;
	self.desTxt:setLocation(-posX + 25, 0);
	self.lockIcon:setLocation(posX - 30, 0);
	self.selectIcon:setLocation(posX - 20, 0);

	if self._data.desDic ~= nil then
		local desPosX = self._data.desDic.desPosX == nil and -posX + 20 or self._data.desDic.desPosX;
		self.desTxt.pivot = self._data.desDic.pivot == nil and UIUtils.Pivot.Left or self._data.desDic.pivot;
		self.desTxt.fontSize = self._data.desDic.fontSize == nil and 26 or self._data.desDic.fontSize;
		self.desTxt.alignmentValue = self._data.desDic.alignmentValue == nil and 3 or self._data.desDic.alignmentValue;
		self.desTxt.colorStr = self._data.desDic.colorStr == nil and Lua_ColorDefine.transColorStr("7A6A5E") or Lua_ColorDefine.transColorStr(self._data.desDic.colorStr);
		self.desTxt:setLocation(desPosX, 0);
	end

	if self._data.lockPosX ~= nil and self._data.lockPosY ~= nil then
		local lockPosX = self._data.desDic.lockPosX == nil and posX - 20 or self._data.desDic.lockPosX;
		self.lockIcon:setLocation(self._data.lockPosX, 0);
	end

	if self._data.selectPosX ~= nil and self._data.selectPosY ~= nil then
		local selectPosX = self._data.desDic.selectPosX == nil and posX - 20 or self._data.desDic.selectPosX;
		self.selectIcon:setLocation(self._data.selectPosX, 0);
	end
end

function Lua_ScreenSelectCell:onPressClick()
	if self._data == nil then
		return;
	end

	if not self._data.isUnlock then
		if self._data.select_type == 1 then
			OperateAlert.showLangValue(420030);
		else
			OperateAlert.showLangValue(420121);
		end
		return;
	end

	Lua_MsgUtil.callFunc("ON_SCREEN_SELECT_CELL", self._data.index);
	return true;
end

function Lua_ScreenSelectCell:onSelectionChange(bSelect)
	self:superCall("onSelectionChange", bSelect);
	self.selectIcon:setEnable(bSelect);
end

function Lua_ScreenSelectCell:dispose()
	self._data = nil;
	self:superCall("dispose");
end